@@ -5,11 +5,11 @@
    *
    * Author: Henrik Austad <henrik.austad@uninett.no>
    */
-require_once 'mdb2_wrapper.php';
-require_once 'logger.php';
+require_once 'MDB2Wrapper.php';
+require_once 'Logger.php';
 require_once 'csr_lib.php';
-require_once 'config.php';
-require_once 'mail_manager.php';
+require_once 'Config.php';
+require_once 'MailManager.php';
 
 abstract class CA
 {
@@ -285,7 +285,7 @@ abstract class CA
 			$msg = $tpl->fetch($custom_template);
 		} else {
 			$default_template = Config::get_config('install_path') .
-				'/lib/smarty/templates/email/notification.tpl';
+				ConfusaConstants::$SMARTY_TEMPLATES . 'email/notification.tpl';
 			$msg = $tpl->fetch($default_template);
 		}
 	}
@@ -368,7 +368,7 @@ abstract class CA
 				$dn .= "/O=" . $this->person->getSubscriber()->getOrgName();
 			}
 
-			$dn .= "/CN=" . $this->person->getX509ValidCN();
+			$dn .= "/CN=" . stripslashes($this->person->getX509ValidCN());
 			$dn .= "/unstructuredName=" . $this->person->getEPPN();
 		} else { /* eScience */
 
@@ -376,7 +376,7 @@ abstract class CA
 				$dn .= "/O=" . Output::mapUTF8ToASCII($this->person->getSubscriber()->getOrgName());
 			}
 
-			$dn .= "/CN=" . $this->person->getX509ValidCN();
+			$dn .= "/CN=" . stripslashes($this->person->getX509ValidCN());
 		}
 
 		return $dn;
@@ -401,11 +401,11 @@ abstract class CA
 
 		if (Config::get_config('cert_product') == PRD_PERSONAL) {
 			$dn .= "O=" . $this->person->getSubscriber()->getOrgName() . ", ";
-			$dn .= "CN=" . $this->person->getX509ValidCN();
+			$dn .= "CN=" . stripslashes($this->person->getX509ValidCN());
 			$dn .= "/unstructuredName=" . $this->person->getEPPN();
 		} else { /* eScience */
 			$dn .= "O=" . Output::mapUTF8ToASCII($this->person->getSubscriber()->getOrgName()) . ", ";
-			$dn .= "CN=" . $this->person->getX509ValidCN();
+			$dn .= "CN=" . stripslashes($this->person->getX509ValidCN());
 		}
 
 		return $dn;
