@@ -43,7 +43,7 @@ function test_content($content, $auth_url)
   /*
    * test length of pubkey
    */
-  $length = Config::get_config('key_length');
+  $length = Config::get_config('min_key_length');
   if (csr_pubkey_length($content) < $length) {
 	  Framework::error_output("Uploaded key is not long enough. Please download a proper keyscript and try again.");
        return false;
