@@ -187,7 +187,7 @@ class CP_NREN_Admin extends Content_Page
 		if (!$this->person->isNRENAdmin()) {
 			$errorTag = PW::create();
 			Logger::logEvent(LOG_NOTICE, "NRENAdmin", "process()",
-			                  "User " . $this->person->getX509ValidCN() . " tried to access the NREN-area",
+			                  "User " . stripslashes($this->person->getX509ValidCN()) . " tried to access the NREN-area",
 			                  __LINE__, $errorTag);
 			$this->tpl->assign('reason', "[$errorTag] You are not an NREN-admin");
 			$this->tpl->assign('content', $this->tpl->fetch('restricted_access.tpl'));
@@ -231,7 +231,18 @@ class CP_NREN_Admin extends Content_Page
 		} else {
 			/* get all info from database and publish to template */
 			$this->tpl->assign('subscriber_list'	, $this->getSubscribers());
-			$this->tpl->assign('self_subscriber'	, $this->person->getSubscriber()->getIdPName());
+			$subscriber = $this->person->getSubscriber();
+
+			if (isset($subscriber)) {
+				$this->tpl->assign('self_subscriber', $subscriber);
+			} else {
+				$this->tpl->assign('self_subscriber', '');
+				Framework::error_output($this->translateTag('l10n_error_illegalattributemap', 'nrenadmin')
+				                        . '<a href="attributes.php">' .
+				                        $this->translateTag('item_attributes', 'menu') .
+				                        '</a>.');
+			}
+
 			$this->tpl->assign('list_subscribers', true);
 		}
 
