@@ -177,7 +177,7 @@ class CP_RevokeCertificate extends Content_Page
 	{
 		if (!$this->person->isAdmin()) {
 			Logger::log_event(LOG_ALERT,
-					  "User " . $this->person->getX509ValidCN() .
+					  "User " . stripslashes($this->person->getX509ValidCN()) .
 					  " allowed to set admin-mode, but is not admin");
 			Framework::error_output("Impossible condition. NON-Admin user in admin-mode!");
 			return;
@@ -603,7 +603,8 @@ class CP_RevokeCertificate extends Content_Page
 				$cn = $this->person->getX509ValidCN();
 				$subscriber = $this->person->getSubscriber()->getOrgName();
 
-				if (($info['cert_owner'] === $cn) && ($info['organization'] === $subscriber)) {
+				if ((stripslashes($info['cert_owner']) === stripslashes($cn)) &&
+				   ($info['organization'] === $subscriber)) {
 					return true;
 				}
 			}
